@@ -2,7 +2,7 @@
 
 
 from django.db import migrations, models
-import djangocms_charts.base.models
+import djangocms_charts.models
 
 
 class Migration(migrations.Migration):
@@ -27,10 +27,10 @@ class Migration(migrations.Migration):
                 ('title_display', models.BooleanField(default=True, verbose_name='Display Title')),
                 ('legend_display', models.BooleanField(default=True, verbose_name='Display Legend')),
                 ('legend_position', models.CharField(max_length=100, verbose_name='Legend Position')),
-                ('chart_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart', blank=True)),
-                ('chart_container_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart Container', blank=True)),
-                ('chart_title_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart Title', blank=True)),
-                ('legend_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Legend', blank=True)),
+                ('chart_classes', models.TextField(verbose_name='Additional classes for Chart', blank=True)),
+                ('chart_container_classes', models.TextField( verbose_name='Additional classes for Chart Container', blank=True)),
+                ('chart_title_classes', models.TextField( verbose_name='Additional classes for Chart Title', blank=True)),
+                ('legend_classes', models.TextField( verbose_name='Additional classes for Legend', blank=True)),
                 ('option_scaleBeginAtZero', models.BooleanField(default=True, verbose_name='Scale should start at zero, or an order of magnitude down from the lowest value')),
                 ('option_scaleShowGridLines', models.BooleanField(default=True, verbose_name='Grid lines are shown across the chart')),
                 ('option_scaleGridLineColor', models.CharField(default=b'rgba(0,0,0,.05)', max_length=300, verbose_name='Colour of the grid lines', blank=True)),
@@ -62,10 +62,10 @@ class Migration(migrations.Migration):
                 ('title_display', models.BooleanField(default=True, verbose_name='Display Title')),
                 ('legend_display', models.BooleanField(default=True, verbose_name='Display Legend')),
                 ('legend_position', models.CharField(max_length=100, verbose_name='Legend Position')),
-                ('chart_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart', blank=True)),
-                ('chart_container_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart Container', blank=True)),
-                ('chart_title_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart Title', blank=True)),
-                ('legend_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Legend', blank=True)),
+                ('chart_classes', models.TextField(verbose_name='Additional classes for Chart', blank=True)),
+                ('chart_container_classes', models.TextField(verbose_name='Additional classes for Chart Container', blank=True)),
+                ('chart_title_classes', models.TextField( verbose_name='Additional classes for Chart Title', blank=True)),
+                ('legend_classes', models.TextField( verbose_name='Additional classes for Legend', blank=True)),
                 ('option_segmentShowStroke', models.BooleanField(default=True, verbose_name='Show a stroke on each segment')),
                 ('option_segmentStrokeColor', models.CharField(default=b'#fff', max_length=300, verbose_name='The colour of each segment stroke', blank=True)),
                 ('option_segmentStrokeWidth', models.IntegerField(default=2, null=True, verbose_name='The width of each segment stroke', blank=True)),
@@ -146,10 +146,10 @@ class Migration(migrations.Migration):
                 ('title_display', models.BooleanField(default=True, verbose_name='Display Title')),
                 ('legend_display', models.BooleanField(default=True, verbose_name='Display Legend')),
                 ('legend_position', models.CharField(max_length=100, verbose_name='Legend Position')),
-                ('chart_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart', blank=True)),
-                ('chart_container_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart Container', blank=True)),
-                ('chart_title_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart Title', blank=True)),
-                ('legend_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Legend', blank=True)),
+                ('chart_classes', models.TextField(verbose_name='Additional classes for Chart', blank=True)),
+                ('chart_container_classes', models.TextField( verbose_name='Additional classes for Chart Container', blank=True)),
+                ('chart_title_classes', models.TextField(verbose_name='Additional classes for Chart Title', blank=True)),
+                ('legend_classes', models.TextField(verbose_name='Additional classes for Legend', blank=True)),
                 ('option_scaleShowGridLines', models.BooleanField(default=True, verbose_name='Grid lines are shown across the chart')),
                 ('option_scaleGridLineColor', models.CharField(default=b'rgba(0,0,0,.05)', max_length=300, verbose_name='Colour of the grid lines', blank=True)),
                 ('option_scaleGridLineWidth', models.IntegerField(default=1, null=True, verbose_name='Width of the grid lines', blank=True)),
@@ -185,10 +185,10 @@ class Migration(migrations.Migration):
                 ('title_display', models.BooleanField(default=True, verbose_name='Display Title')),
                 ('legend_display', models.BooleanField(default=True, verbose_name='Display Legend')),
                 ('legend_position', models.CharField(max_length=100, verbose_name='Legend Position')),
-                ('chart_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart', blank=True)),
-                ('chart_container_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart Container', blank=True)),
-                ('chart_title_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart Title', blank=True)),
-                ('legend_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Legend', blank=True)),
+                ('chart_classes', models.TextField( verbose_name='Additional classes for Chart', blank=True)),
+                ('chart_container_classes', models.TextField(verbose_name='Additional classes for Chart Container', blank=True)),
+                ('chart_title_classes', models.TextField(verbose_name='Additional classes for Chart Title', blank=True)),
+                ('legend_classes', models.TextField(verbose_name='Additional classes for Legend', blank=True)),
                 ('option_segmentShowStroke', models.BooleanField(default=True, verbose_name='Show a stroke on each segment')),
                 ('option_segmentStrokeColor', models.CharField(default=b'#fff', max_length=300, verbose_name='The colour of each segment stroke', blank=True)),
                 ('option_segmentStrokeWidth', models.IntegerField(default=2, null=True, verbose_name='The width of each segment stroke', blank=True)),
@@ -218,10 +218,10 @@ class Migration(migrations.Migration):
                 ('title_display', models.BooleanField(default=True, verbose_name='Display Title')),
                 ('legend_display', models.BooleanField(default=True, verbose_name='Display Legend')),
                 ('legend_position', models.CharField(max_length=100, verbose_name='Legend Position')),
-                ('chart_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart', blank=True)),
-                ('chart_container_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart Container', blank=True)),
-                ('chart_title_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart Title', blank=True)),
-                ('legend_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Legend', blank=True)),
+                ('chart_classes', models.TextField( verbose_name='Additional classes for Chart', blank=True)),
+                ('chart_container_classes', models.TextField( verbose_name='Additional classes for Chart Container', blank=True)),
+                ('chart_title_classes', models.TextField( verbose_name='Additional classes for Chart Title', blank=True)),
+                ('legend_classes', models.TextField( verbose_name='Additional classes for Legend', blank=True)),
                 ('option_scaleShowLabelBackdrop', models.BooleanField(default=True, verbose_name='Show a backdrop to the scale label')),
                 ('option_scaleBackdropColor', models.CharField(default=b'rgba(255,255,255,0.75)', max_length=300, verbose_name='The colour of the label backdrop', blank=True)),
                 ('option_scaleBeginAtZero', models.BooleanField(default=True, verbose_name='Scale should begin at zero')),
@@ -256,10 +256,10 @@ class Migration(migrations.Migration):
                 ('title_display', models.BooleanField(default=True, verbose_name='Display Title')),
                 ('legend_display', models.BooleanField(default=True, verbose_name='Display Legend')),
                 ('legend_position', models.CharField(max_length=100, verbose_name='Legend Position')),
-                ('chart_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart', blank=True)),
-                ('chart_container_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart Container', blank=True)),
-                ('chart_title_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Chart Title', blank=True)),
-                ('legend_classes', models.TextField(default=djangocms_charts.base.models.get_chart_class, verbose_name='Additional classes for Legend', blank=True)),
+                ('chart_classes', models.TextField( verbose_name='Additional classes for Chart', blank=True)),
+                ('chart_container_classes', models.TextField( verbose_name='Additional classes for Chart Container', blank=True)),
+                ('chart_title_classes', models.TextField( verbose_name='Additional classes for Chart Title', blank=True)),
+                ('legend_classes', models.TextField( verbose_name='Additional classes for Legend', blank=True)),
                 ('option_scaleShowLine', models.BooleanField(default=True, verbose_name='Show lines for each scale point')),
                 ('option_angleShowLineOut', models.BooleanField(default=True, verbose_name='Show the angle lines out of the radar')),
                 ('option_scaleShowLabels', models.BooleanField(default=False, verbose_name='Show labels on the scale')),
